# Load package libraries
library(dplyr)
library(ggplot2)
library(ggpubr)
library(ggfortify)
library(wesanderson)

# Load data frame
setwd("C:/Users/ajjb8/Desktop/Jimena/Doutorado/Poster CH/JImena_Poster")
df<-read.csv("porcentajes ovocitos.csv", sep= ",", dec=".")
ggscatter(df, x = "Bell.height", y = "Oiii.", 
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE, cor.method = "pearson",
          xlab = "Individual Size", ylab = "Porcentage")
head(df,6)

df <-porcentajes_ovocitos
summary(df)

df_1 <-as.data.frame(df) #as dataframe
df_1
summary(df_1)

str(df_1)

glimpse(df_1)
tbl_df(df_1)
tibble::as_tibble(df_1)

hist(df_1$`Oiii%`)

shapiro.test(df_1$Bell.height)

#Spearman correlation
df<-read.csv("porcentajes ovocitos.csv", na.strings=c("","NA"))
str(df)
summary(df)

ggscatter(df, x = "IPD", y = "Oiii.",
          add = "reg.line", conf.int = TRUE,
          cor.coef = TRUE, cor.method = "spearman",
          xlab = "Individual Size", ylab = "Porcentage")

shapiro.test(df$IPD)

# Average diameters per oocyte stage
df1<-read.csv("Chiropsalmus_q.csv", na.strings=c("","NA"), sep= ",", dec=".")
summary(df1)

df_2 <-as.data.frame(df1) #Convertir dataframe
df_2
summary(df_2)

str(df_2)
#reorder "Stage" levels
df_2$Stage=forcats::fct_relevel (df$Stage, "Pre-vitellogenic (P)",'Early vitellogenic (Oi)','Mid-vitellogenic (Oii)', 'Late vitellogenic (Oiii)')

summarise(
  group_by(df_2, Stage),
  meanSize = mean(Size))

#Graphics oocyte stages
ggplot(df_2, aes(x = Stage, y = Size)) +
  geom_point() +
  theme_bw()

ggplot(df_2, aes(x = Stage, y = Size, colour = Stage)) +
  geom_point(size = 2) +
  xlab("Stage Development") +
  ylab("Size Oocyte") +
  theme_bw()

mycols=(c("deepskyblue4","deepskyblue3","darkturquoise","seagreen1"))
mycols<-mycols(4); #Set levels
mycols2<-paste(mycols, "99", sep="")# set transparency


ggplot(df_2, aes(x = Stage, y = Size)) +
  geom_boxplot(fill=mycols) +
  geom_point(size = 4, colour = 'lightgrey', alpha = 0.5) +
  xlab("Oocyte stage") +
  ylab("Oocyte size (m)") +
  theme_bw()

ggplot(df1, aes(x = Size,fill = Stage)) +
geom_histogram(binwidth = 10) +
facet_wrap(~ Stage, ncol = 1) +
scale_fill_manual(values=mycols)+
theme(strip.background = element_rect(fill="white",colour="black"))+ 
  theme(legend.position="none",
        legend.justification=c(1,1),
        legend.key = element_rect(fill = 'transparent'),
        legend.background = element_rect(fill = 'transparent'),
        legend.text = element_text(size = 12))

#Graphics b/w
ggplot(df1, aes(x = Size)) +
  geom_histogram(binwidth = 10) +
  facet_wrap(~ Stage, ncol = 1) +
  theme_bw()

ggplot(df_2, aes(x = Stage, y = Size)) +
  geom_boxplot() +
  theme_bw()

#calculate sd per stage 
group_by(df_2, Stage) %>%
  summarise(
    count = n(),
    mean = mean(Size, na.rm = TRUE),
    sd = sd(Size, na.rm = TRUE))

#Anova
model_grow <- lm(Size ~ Stage, data = df_2)
model_grow

autoplot(model_grow, smooth.colour = NA)

anova(model_grow)

summary(model_grow)

#
ggboxplot(df_2, x = "Stage", y = "Size", 
          color = "Stage", palette = c("#00AFBB", "#E7B800", "#FC4E07", "#B2182B"),
          order = c("P", "Oi", "Oii", "Oiii"),
          ylab = "Size", xlab = "Stage")

res.aov <- aov(Size ~ Stage, data = df_2)

TukeyHSD(res.aov)

#correlation oocyte size, oocyte stages
kruskal.test(Size ~ Stage, data = df_2)

